@@ -35,6 +35,13 @@ const (
 	InstanceResizing     InstanceStatus = "resizing"
 )
 
+type InstanceMigrationType string
+
+const (
+	WarmMigration InstanceMigrationType = "warm"
+	ColdMigration InstanceMigrationType = "cold"
+)
+
 // Instance represents a linode object
 type Instance struct {
 	ID              int             `json:"id"`
@@ -107,22 +114,23 @@ type InstanceMetadataOptions struct {
 
 // InstanceCreateOptions require only Region and Type
 type InstanceCreateOptions struct {
-	Region          string                    `json:"region"`
-	Type            string                    `json:"type"`
-	Label           string                    `json:"label,omitempty"`
-	Group           string                    `json:"group,omitempty"`
-	RootPass        string                    `json:"root_pass,omitempty"`
-	AuthorizedKeys  []string                  `json:"authorized_keys,omitempty"`
-	AuthorizedUsers []string                  `json:"authorized_users,omitempty"`
-	StackScriptID   int                       `json:"stackscript_id,omitempty"`
-	StackScriptData map[string]string         `json:"stackscript_data,omitempty"`
-	BackupID        int                       `json:"backup_id,omitempty"`
-	Image           string                    `json:"image,omitempty"`
-	Interfaces      []InstanceConfigInterface `json:"interfaces,omitempty"`
-	BackupsEnabled  bool                      `json:"backups_enabled,omitempty"`
-	PrivateIP       bool                      `json:"private_ip,omitempty"`
-	Tags            []string                  `json:"tags,omitempty"`
-	Metadata        *InstanceMetadataOptions  `json:"metadata,omitempty"`
+	Region          string                                 `json:"region"`
+	Type            string                                 `json:"type"`
+	Label           string                                 `json:"label,omitempty"`
+	Group           string                                 `json:"group,omitempty"`
+	RootPass        string                                 `json:"root_pass,omitempty"`
+	AuthorizedKeys  []string                               `json:"authorized_keys,omitempty"`
+	AuthorizedUsers []string                               `json:"authorized_users,omitempty"`
+	StackScriptID   int                                    `json:"stackscript_id,omitempty"`
+	StackScriptData map[string]string                      `json:"stackscript_data,omitempty"`
+	BackupID        int                                    `json:"backup_id,omitempty"`
+	Image           string                                 `json:"image,omitempty"`
+	Interfaces      []InstanceConfigInterfaceCreateOptions `json:"interfaces,omitempty"`
+	BackupsEnabled  bool                                   `json:"backups_enabled,omitempty"`
+	PrivateIP       bool                                   `json:"private_ip,omitempty"`
+	Tags            []string                               `json:"tags,omitempty"`
+	Metadata        *InstanceMetadataOptions               `json:"metadata,omitempty"`
+	FirewallID      int                                    `json:"firewall_id,omitempty"`
 
 	// Creation fields that need to be set explicitly false, "", or 0 use pointers
 	SwapSize *int  `json:"swap_size,omitempty"`
@@ -191,12 +199,19 @@ type InstanceCloneOptions struct {
 
 // InstanceResizeOptions is an options struct used when resizing an instance
 type InstanceResizeOptions struct {
-	Type string `json:"type"`
+	Type          string                `json:"type"`
+	MigrationType InstanceMigrationType `json:"migration_type,omitempty"`
 
 	// When enabled, an instance resize will also resize a data disk if the instance has no more than one data disk and one swap disk
 	AllowAutoDiskResize *bool `json:"allow_auto_disk_resize,omitempty"`
 }
 
+// InstanceResizeOptions is an options struct used when resizing an instance
+type InstanceMigrateOptions struct {
+	Type   InstanceMigrationType `json:"type,omitempty"`
+	Region string                `json:"region,omitempty"`
+}
+
 // InstancesPagedResponse represents a linode API response for listing
 type InstancesPagedResponse struct {
 	*PageOptions
@@ -416,8 +431,14 @@ func (c *Client) MutateInstance(ctx context.Context, id int) error {
 }
 
 // MigrateInstance - Migrate an instance
-func (c *Client) MigrateInstance(ctx context.Context, id int) error {
-	return c.simpleInstanceAction(ctx, "migrate", id)
+func (c *Client) MigrateInstance(ctx context.Context, linodeID int, opts InstanceMigrateOptions) error {
+	body, err := json.Marshal(opts)
+	if err != nil {
+		return err
+	}
+	e := fmt.Sprintf("linode/instances/%d/migrate", linodeID)
+	_, err = coupleAPIErrors(c.R(ctx).SetBody(string(body)).Post(e))
+	return err
 }
 
 // simpleInstanceAction is a helper for Instance actions that take no parameters
