@@ -79,6 +79,45 @@ func TestInstance_Get_smoke(t *testing.T) {
 	assertDateSet(t, instance.Updated)
 }
 
+func TestInstance_Resize(t *testing.T) {
+	client, instance, teardown, err := setupInstance(
+		t,
+		"fixtures/TestInstance_Resize",
+		func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
+			boot := true
+			options.Type = "g6-nanode-1"
+			options.Booted = &boot
+		},
+	)
+	
+	defer teardown()
+	if err != nil {
+		t.Error(err)
+	}
+
+	instance, err = client.WaitForInstanceStatus(
+		context.Background(),
+		instance.ID,
+		linodego.InstanceRunning,
+		180,
+	)
+	if err != nil {
+		t.Errorf("Error waiting for instance readiness for resize: %s", err.Error())
+	}
+
+	err = client.ResizeInstance(
+		context.Background(),
+		instance.ID,
+		linodego.InstanceResizeOptions{
+			Type: "g6-standard-1",
+			MigrationType: "warm",
+		},
+	)
+	if err != nil {
+		t.Errorf("failed to resize instance %d: %v", instance.ID, err.Error())
+	}
+}
+
 func TestInstance_Disks_List(t *testing.T) {
 	client, instance, teardown, err := setupInstance(t, "fixtures/TestInstance_Disks_List")
 	defer teardown()
@@ -180,7 +219,7 @@ func TestInstance_Disk_ListMultiple(t *testing.T) {
 	_, err = client.CreateInstanceDisk(context.Background(), instance2.ID, linodego.InstanceDiskCreateOptions{
 		Label:    "go-disk-test-" + randLabel(),
 		Image:    image.ID,
-		RootPass: "R34lBAdP455LONGLONGLONGLONG",
+		RootPass: randPassword(),
 		Size:     2000,
 	})
 	if err != nil {
@@ -221,7 +260,7 @@ func TestInstance_Disk_ResetPassword(t *testing.T) {
 		Label:      "go-disk-test-" + randLabel(),
 		Filesystem: "ext4",
 		Image:      "linode/debian9",
-		RootPass:   "R34lBAdP455LONGLONGLONGLONG",
+		RootPass:   randPassword(),
 		Size:       2000,
 	})
 	if err != nil {
@@ -329,7 +368,7 @@ func TestInstance_Rebuild(t *testing.T) {
 		Metadata: &linodego.InstanceMetadataOptions{
 			UserData: base64.StdEncoding.EncodeToString([]byte("cool")),
 		},
-		RootPass: "R34lBAdP455LONGLONGLONGLONG",
+		RootPass: randPassword(),
 		Type:     "g6-standard-2",
 	}
 	instance, err = client.RebuildInstance(context.Background(), instance.ID, rebuildOpts)
@@ -451,7 +490,7 @@ func createInstance(t *testing.T, client *linodego.Client, modifiers ...instance
 	booted := false
 	createOpts := linodego.InstanceCreateOptions{
 		Label:    "go-test-ins-" + randLabel(),
-		RootPass: "R34lBAdP455LONGLONGLONGLONG",
+		RootPass: randPassword(),
 		Region:   getRegionsWithCaps(t, client, []string{"linodes"})[0],
 		Type:     "g6-nanode-1",
 		Image:    "linode/debian9",
