@@ -3,6 +3,8 @@ package integration
 import (
 	"context"
 	"testing"
+
+	"github.com/jarcoal/httpmock"
 )
 
 func TestObjectStorage_Get_Transfer(t *testing.T) {
@@ -16,14 +18,15 @@ func TestObjectStorage_Get_Transfer(t *testing.T) {
 }
 
 func TestObjectStorage_Cancel(t *testing.T) {
-	// TODO: add object-storage/enable to test for repeatability
-	t.Skip("Unable to enable Object Storage via the API, update test with /enable when available")
+	client := createMockClient(t)
 
-	client, teardown := createTestClient(t, "fixtures/TestObjectStorage_cancel")
-	defer teardown()
+	desiredResponse := make(map[string]interface{})
+
+	httpmock.RegisterRegexpResponder("POST", mockRequestURL(t, "/object-storage/cancel"),
+		httpmock.NewJsonResponderOrPanic(200, &desiredResponse))
 
 	err := client.CancelObjectStorage(context.Background())
 	if err != nil {
-		t.Errorf("failed to cancel object storage : %s", err)
+		t.Fatal(err)
 	}
 }
